diff --git a/examples/Scripts/BlendModes.html b/examples/Scripts/BlendModes.html
index ca1af0eb..041fd6ec 100644
--- a/examples/Scripts/BlendModes.html
+++ b/examples/Scripts/BlendModes.html
@@ -37,9 +37,9 @@
justification: 'center',
content: mode
})
- var clip = new Group(rect, img, text);
- clip.position = point;
- all.addChild(clip);
+ var group = new Group(rect, img, text);
+ group.position = point;
+ all.addChild(group);
}
var modes = [ 'normal', 'multiply', 'screen', 'overlay', 'soft-light',
diff --git a/src/svg/SVGExport.js b/src/svg/SVGExport.js
index 9f99aeb6..14287dee 100644
--- a/src/svg/SVGExport.js
+++ b/src/svg/SVGExport.js
@@ -461,9 +461,9 @@ new function() {
getDefinition();
// Have different id ranges per type
var id = definitions.ids[type] = (definitions.ids[type] || 0) + 1;
// Give the svg node an id, and link to it from the id.
node.id = type + '-' + id;
- definitions.svgs[node.id] = node;
+ definitions.svgs[type + '-' + item._id] = node;
}
function exportDefinitions(node) {
@@ -461,9 +461,9 @@ new function() {
// Have different id ranges per type
var id = definitions.ids[type] = (definitions.ids[type] || 0) + 1;
- // Give the svg node an id, and link to it from the id.
+ // Give the svg node an id, and link to it from the item id.
node.id = type + '-' + id;